==> verttice_ui-0.0.153.tar.gz: lib/src/widgets/themed_widgets/themed_text_button.dart <==
// 🐦 Flutter imports:
import "package:flutter/material.dart";

// 📦 Package imports:
import 'package:fluent_ui/fluent_ui.dart' as fluent;

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

class ThemedTextButton extends StatelessWidget {
  final String text;
  final Function() onPressed;
  final bool offMode;
  final bool showLoading;
  final Color? color;
  final TextStyle? textStyle;
  final BoxFit fit;

  const ThemedTextButton(
    this.text, {
    Key? key,
    required this.onPressed,
    this.offMode = false,
    this.showLoading = false,
    this.color,
    this.textStyle,
    this.fit = BoxFit.scaleDown,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return FittedBox(
      fit: fit,
      child: fluent.FilledButton(
        onPressed: onPressed,
        style: fluent.ButtonStyle(
          backgroundColor: offMode
              ? fluent.ButtonState.all(Colors.grey[150])
              : fluent.ButtonState.all(color),
        ),
        child: Center(
          child: Row(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              fluent.Text(
                text,
                style: ThemedFonts.primary(
                  textStyle: textStyle,
                ),
              ),
              if (showLoading)
                const Padding(
                  padding: EdgeInsets.symmetric(horizontal: 15),
                  child: ThemedProgress(),
                )
            ],
          ),
        ),
      ),
    );
  }
}

==> verttice_ui-0.1.2.tar.gz: lib/src/widgets/themed_widgets/themed_text_button.dart <==
// 🐦 Flutter imports:
import "package:flutter/material.dart";

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

class ThemedTextButton extends StatelessWidget {
  final String text;
  final Function() onPressed;
  final bool offMode;
  final bool showLoading;
  final Color? color;
  final TextStyle? textStyle;
  final BoxFit fit;

  const ThemedTextButton(
    this.text, {
    Key? key,
    required this.onPressed,
    this.offMode = false,
    this.showLoading = false,
    this.color,
    this.textStyle,
    this.fit = BoxFit.scaleDown,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return FittedBox(
      fit: fit,
      child: ElevatedButton(
        onPressed: onPressed,
        style: ButtonStyle(
          backgroundColor: offMode
              ? MaterialStateProperty.all(Colors.grey[150])
              : MaterialStateProperty.all(color),
        ),
        child: Center(
          child: Row(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Text(
                text,
                style: ThemedFonts.primary(
                  textStyle: textStyle,
                ),
              ),
              if (showLoading)
                const Padding(
                  padding: EdgeInsets.symmetric(horizontal: 15),
                  child: ThemedProgress(),
                )
            ],
          ),
        ),
      ),
    );
  }
}
